/*
 * Created by sweetbread
 * Copyright (c) 2025. All rights reserved.
 * Last modified 03.03.2025, 20:22
 */

package ru.risdeveau.pixeldragon.ui.activity

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults.topAppBarColors
import androidx.compose.ui.Modifier
import androidx.navigation.NavType
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navArgument
import ru.risdeveau.pixeldragon.ui.layout.Room
import ru.risdeveau.pixeldragon.ui.layout.RoomList
import ru.risdeveau.pixeldragon.ui.theme.PixelDragonTheme

class MainActivity : ComponentActivity() {
    @OptIn(ExperimentalMaterial3Api::class)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        enableEdgeToEdge()
        setContent {
            PixelDragonTheme {
                Scaffold(
                    modifier = Modifier.fillMaxSize(),
                    topBar = {
                        TopAppBar(
                            colors = topAppBarColors(
                                containerColor = MaterialTheme.colorScheme.primaryContainer,
                                titleContentColor = MaterialTheme.colorScheme.primary,
                            ),
                            title = {
                                Text("Top app bar")
                            }
                        )
                    },
                ) { innerPadding ->
                    val navController = rememberNavController()

                    NavHost(navController = navController, startDestination = "rooms") {
                        composable("rooms") { RoomList(Modifier.padding(innerPadding), navController) }
                        composable(
                            "room/{rid}",
                            arguments = listOf(navArgument("rid") { type = NavType.StringType })
                        ) { navBackStackEntry ->
                            Room(Modifier.padding(innerPadding).fillMaxSize(), navBackStackEntry.arguments!!.getString("rid")!!)
                        }
                        composable(
                            "space/{rid}",
                            arguments = listOf(navArgument("rid") { type = NavType.StringType })
                        ) { navBackStackEntry ->
                            Text(modifier = Modifier.padding(innerPadding), text = "Not implemented") }
                    }
                }
            }
        }
    }
}
