/*
 * Created by sweetbread
 * Copyright (c) 2025. All rights reserved.
 * Last modified 03.03.2025, 21:30
 */

package ru.risdeveau.pixeldragon.ui.layout

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.lazy.rememberLazyListState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import ru.risdeveau.pixeldragon.api.Event
import ru.risdeveau.pixeldragon.api.getAccountData
import ru.risdeveau.pixeldragon.api.getEventsAround
import ru.risdeveau.pixeldragon.api.getMe

@Composable
fun Room(modifier: Modifier = Modifier, rid: String) {
    var eventsId by remember { mutableStateOf(listOf<Event>()) }
    val coroutineScope = rememberCoroutineScope()
    val listState = rememberLazyListState()

    LaunchedEffect(true) {
        coroutineScope.launch {
            withContext(Dispatchers.IO) {
                val readMark = getAccountData(getMe()!!.userId, rid, "m.fully_read")
                val eventsAround = getEventsAround(rid, readMark!!.getString("event_id"))  //FIXME: Null check
                eventsId = eventsAround.let {
                    it.before + listOf(it.base) + it.after
                }
            }
        }
    }

    LazyColumn(modifier = modifier, state = listState, reverseLayout = true) {
        items(eventsId.reversed()) { event ->
            EventItem(event)
        }

        item {
            if (eventsId.isEmpty()) {
                Text("Empty room")
            }
        }
    }
}

@Composable
fun EventItem(event: Event) {
    Box (Modifier.fillMaxWidth()) {
        when (event.type) {
            "m.room.message" -> Column(
                Modifier
                    .align(Alignment.CenterStart)
                    .padding(4.dp)
                    .background(
                        color = MaterialTheme.colorScheme.surfaceContainer,
                        shape = RoundedCornerShape(16.dp)
                    )
                    .padding(4.dp)
            ) {
                Text(event.sender, maxLines = 1, fontWeight = FontWeight.Bold)
                Text(event.content.getString("body"))
            }
            else -> Text(event.type, Modifier.padding(4.dp).background(MaterialTheme.colorScheme.errorContainer).padding(4.dp))
        }
    }
}