/*
 * Created by sweetbread
 * Copyright (c) 2025. All rights reserved.
 * Last modified 03.03.2025, 20:22
 */

package ru.risdeveau.pixeldragon.ui.layout

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.lazy.rememberLazyListState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import coil3.compose.SubcomposeAsyncImage
import coil3.network.NetworkHeaders
import coil3.network.httpHeaders
import coil3.request.ImageRequest
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import ru.risdeveau.pixeldragon.api.getRoom
import ru.risdeveau.pixeldragon.api.getRooms
import ru.risdeveau.pixeldragon.api.mxcToUrl
import ru.risdeveau.pixeldragon.db.Room
import ru.risdeveau.pixeldragon.token
import splitties.init.appCtx

@Composable
fun RoomList(modifier: Modifier = Modifier, navController: NavController) {
    var list by remember { mutableStateOf(listOf<String>()) }
    val coroutineScope = rememberCoroutineScope()
    val listState = rememberLazyListState()

//    if (itemState.scrollToTop) {
//        LaunchedEffect(coroutineScope) {
//            Log.e("TAG", "TopCoinsScreen: scrollToTop" )
//            listState.scrollToItem(0)
//        }
//    }

    LaunchedEffect(true) {
        coroutineScope.launch {
            withContext(Dispatchers.IO) {
                list = getRooms()
            }
        }
    }

    LazyColumn(modifier = modifier, state = listState) {
        items(list) { rid ->
            RoomItem(rid = rid, navController = navController )
        }

        item {
            if (list.isEmpty()) {
                Text("You have no rooms")
            }
        }
    }
}

@Composable
fun RoomItem(modifier: Modifier = Modifier, rid: String, navController: NavController) {
    var room by remember { mutableStateOf<Room?>(null) }
    val scope = rememberCoroutineScope()

    LaunchedEffect(true) {
        scope.launch {
            withContext(Dispatchers.IO) {
                room = getRoom(rid)
            }
        }
    }

    if (room != null) {
        Row(
            modifier
                .padding(8.dp)
                .height((52 + 8 * 2).dp)
                .fillMaxWidth()
                .background(MaterialTheme.colorScheme.background, RoundedCornerShape(16.dp))
                .padding(8.dp)
                .clickable {
                    if (room!!.type == "m.space")
                        navController.navigate("space/$rid")
                    else
                        navController.navigate("room/$rid")
                }
        ) {
            SubcomposeAsyncImage(
                modifier = Modifier
                    .padding(end = 4.dp)
                    .height(52.dp)
                    .width(52.dp)
                    .let {
                        if (room!!.type == "m.space")
                            it.clip(RoundedCornerShape(12.dp))
                        else
                            it.clip(CircleShape)
                    },
                model = ImageRequest.Builder(appCtx)
                    .data(mxcToUrl(room!!.avatarUrl ?: ""))
                    .httpHeaders(
                        NetworkHeaders.Builder()
                            .set("Authorization", "Bearer $token")
                            .set("Cache-Control", "max-age=86400")
                            .build()
                    )
                    .build(),
                contentDescription = room!!.roomId,
                contentScale = ContentScale.Crop,
                loading = {
                    CircularProgressIndicator()
                }
            )
            Column {
                Text(
                    room!!.name ?: "Unnamed",
                    maxLines = 1,
                    color = MaterialTheme.colorScheme.primary,
                    fontSize = MaterialTheme.typography.titleLarge.fontSize
                )
            }
        }
    } else {
        Row(
            modifier
                .padding(8.dp)
                .height(80.dp)
                .fillMaxWidth()
                .background(MaterialTheme.colorScheme.background, RoundedCornerShape(16.dp))
                .padding(8.dp)
        ) {
            LinearProgressIndicator(Modifier.fillMaxWidth())
        }
    }
}